hamming_similarity: Hamming Similarity

View source: R/RcppExports.R

hamming_similarityR Documentation

Hamming Similarity

Description

Measures the similarity between two strings using the Hamming metric.

Usage

hamming_similarity(s1, s2, pad = TRUE)

Arguments

s1

The first string.

s2

The second string.

pad

If true, the strings are padded to the same length (default: TRUE).

Value

An integer representing the similarity.

Examples

hamming_similarity("karolin", "kathrin")

RapidFuzz documentation built on April 8, 2026, 1:07 a.m.